import { Type } from './metadata/type';
import { Metadata } from './metadata/metadata';
import { Condition } from './interfaces/condition';
import { OrderBy } from './interfaces/orderby';
import { ClientOptions, Client } from './client';
export declare class Redisk {
    private readonly metadata;
    private readonly client;
    constructor(metadata: Metadata, client: Client);
    static init(options: ClientOptions): Redisk;
    close(): Promise<void>;
    getClient(): Client;
    save<T>(entity: T): Promise<void>;
    count<T>(entityType: Type<T>): Promise<number>;
    list<T>(entityType: Type<T>, limit?: number, offset?: number, orderBy?: OrderBy): Promise<T[]>;
    find<T>(entityType: Type<T>, conditions: Condition[], limit?: number, offset?: number, type?: 'AND' | 'OR'): Promise<T[]>;
    search<T>(entityType: Type<T>, condition: Condition, limit: number): Promise<T[]>;
    searchIds<T>(entityType: Type<T>, condition: Condition, limit: number): Promise<string[]>;
    findIds<T>(entityType: Type<T>, conditions: Condition[], type?: 'AND' | 'OR'): Promise<string[]>;
    listIds<T>(entityType: Type<T>, limit?: number, offset?: number, orderBy?: OrderBy): Promise<string[]>;
    delete<T>(entityType: Type<T>, id: string): Promise<void>;
    getOne<T>(entityType: Type<T>, value: any, key?: string): Promise<T>;
    private convertPropertyTypeToPrimitive;
    private convertStringToPropertyType;
    private dropUniqueKeys;
    private dropIndexes;
    private dropSearchables;
    private dropSortables;
    private getIndexKeyName;
    private getListKeyName;
    private getUniqueKeyName;
    private getSortableKeyName;
    private getSearchableKeyName;
    private getSearchableValuePrefix;
}
